<?php

namespace Eform\Filing\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Eform\Filing\Forms\Filings as FilingsForm;
use Eform\Filing\Http\Requests\FilingsResourceRequest;
use Eform\Filing\Http\Resources\FilingsResource;
use Eform\Filing\Http\Resources\FilingsCollection;
use Eform\Filing\Models\Filings;
use Eform\Filing\Actions\FilingsAction;
use Eform\Filing\Actions\FilingsActions;


/**
 * Resource controller class for filings.
 */
class FilingsResourceController extends BaseController
{

    /**
     * Initialize filings resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = FilingsForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('eform.filing.modules'), 'filing', guard_url('filing'));
            return $next($request);
        });
    }

    /**
     * Display a list of filings.
     *
     * @return Response
     */
    public function index(FilingsResourceRequest $request)
    {
        $request = $request->all();
        $page = FilingsActions::run('paginate', $request);

        $data = new FilingsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('filing::filings.names'))
            ->view('filing::filings.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display filings.
     *
     * @param Request $request
     * @param Model   $filings
     *
     * @return Response
     */
    public function show(FilingsResourceRequest $request, Filings $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FilingsResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('filing::filings.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('filing::filings.show')
            ->output();
    }

    /**
     * Show the form for creating a new filings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(FilingsResourceRequest $request, Filings $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FilingsResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('filing::filings.name'))
            ->view('filing::filings.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new filings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(FilingsResourceRequest $request, Filings $model)
    {
        try {
            $request = $request->all();
            $model = FilingsAction::run('store', $model, $request);
            $data = new FilingsResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('filing::filings.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('filing/filings/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/filing/filings'))
                ->redirect();
        }

    }

    /**
     * Show filings for editing.
     *
     * @param Request $request
     * @param Model   $filings
     *
     * @return Response
     */
    public function edit(FilingsResourceRequest $request, Filings $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new FilingsResource($model);
        // return view('filing::filings.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('filing::filings.name'))
            ->view('filing::filings.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the filings.
     *
     * @param Request $request
     * @param Model   $filings
     *
     * @return Response
     */
    public function update(FilingsResourceRequest $request, Filings $model)
    {
        try {
            $request = $request->all();
            $model = FilingsAction::run('update', $model, $request);
            $data = new FilingsResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('filing::filings.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('filing/filings/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('filing/filings/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the filings.
     *
     * @param Model   $filings
     *
     * @return Response
     */
    public function destroy(FilingsResourceRequest $request, Filings $model)
    {
        try {

            $request = $request->all();
            $model = FilingsAction::run('destroy', $model, $request);
            $data = new FilingsResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('filing::filings.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('filing/filings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('filing/filings/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
